   /**
     * 日期选择器
     *
     * @param {Object} options 截屏参数
     * {
     * 		type: 'showYearMonthDayDialog', //日期选择框类型
     *      title: '日期选择', // 标题
     *      startDate: '2012-01-01', // 开始时间
     *      endDate: '2013-01-01', // 结束时间
     *      flag: 1, // 只有Type为showPerWeekOrPerMonthDialog的时候有效，1表示每周弹出框，2表示每月弹出框
     *      isHideAmPm: false, // 只有type为showPerMonthWeekDayDialog时有效，false表示不隐藏上午下午，true表示隐藏上午下午
     * }
     *
     * @examples
     * function showYearMonthDayDialog(){
  	 * 		var options ={ 
  	 *			type: 'showYearMonthDayDialog',
  	 *			title: 'title',
	 *			startDate: '2012-01-01',
	 *			endDate: '2013-04-08'
	 *  	}
     *		Native.showCalendarDialog(options, function(data){alert(data)}, function(error){alert(error)});
  	 *	}
     */
    Native.showCalendarDialog = function(options, onSuccess, onFail) {
        options = options || {};
        var type = options.type;
        var title = options.title || '';
        var startDate = options.startDate || '';
        var endDate = options.endDate || '';
        var flag = options.flag || 0;
        var isHideAmPm = options.isHideAmPm || false;
        var initDate = options.initDate || '';
        cordova.exec(onSuccess, onFail, 'DatePicker', type, [title, startDate, endDate, flag, isHideAmPm, initDate]);
    }
    
    /**
     * 操作菜单下拉框
     *
     * @param {Object} options 参数
     * {
     *      title: '日期选择', // 标题
     *      items: ['delete','add','edit'], // 操作列表信息
     * }
     *
     * @examples
     * function showMenuDialog(){
  	 * 		var options ={ 
  	 *			title: 'title',
	 *			items:  [
	 *	          	'delete',
	 *	          	'add',
	 *	          	'edit'
	 *	     	]
	 *  	}
     *		Native.showMenuDialog(options, function(data){alert(data)}, function(error){alert(error)});
  	 *	}
     */
    Native.showMenuDialog = function(options, onSuccess, onFail) {
        options = options || {};
        var title = options.title || '';
        var items = options.items || [];
        cordova.exec(onSuccess, onFail, 'MenuPlugin', 'showMenuDialog', [title, items]);
    }
    
    Native.showSpinnerDialog = function(options, onSuccess, onFail) {
        options = options || {};
        var title = options.title || '';
        var display = options.display || '';
        var items = options.items || [];
        cordova.exec(onSuccess, onFail, 'MenuPlugin', 'showSpinnerDialog', [title, display, items]);
    }
    
    /**
     * 弹出多项相下拉框
     *
     * @param {Object} options 参数
     * {
     *      title: '日期选择', // 标题
     *      items: ['delete','add','edit'], // 多选些列表信息
     * }
     *
     * @examples
     * function showMultiSelectDialog(){
  	 * 		var options ={ 
  	 *			title: 'title',
	 *			items:  [
	 *	          	'delete',
	 *	          	'add',
	 *	          	'edit'
	 *	     	]
	 *  	}
     *		Native.showMultiSelectDialog(options, function(data){alert(data)}, function(error){alert(error)});
  	 *	}
     */
    Native.showMultiSelectDialog = function(options, onSuccess, onFail) {
        options = options || {};
        var title = options.title || '';
        var items = options.items || [];
        cordova.exec(onSuccess, onFail, 'MenuPlugin', 'showMultiSelectDialog', [title, items]);
    }
    
    Native.showAreaDialog = function(options, onSuccess, onFail) {
        options = options || {};
       	var title = options.title || '';
        var displayProvince = options.displayProvince || '';
        var displayCity = options.displayCity || '';
        var province = options.province || [];
        var city = options.city || [];
        cordova.exec(onSuccess, onFail, 'AreaPicker', 'showAreaDialog', [title, displayProvince, displayCity, province, city]);
    }
    
    /**
     * 3DES加密
     */
    Native.encryptByDESede = function(data, onSuccess, onFail) {
        data = data || {};
        cordova.exec(onSuccess, onFail, 'SecurityPlugin', 'encrypt', [data]);
    }
    
    /**
     * 3DES解密
     */ 
    Native.decryptByDESede = function(data, onSuccess, onFail) {
        data = data || {};
        cordova.exec(onSuccess, onFail, 'SecurityPlugin', 'decrypt', [data]);
    }
    
    /**
     * 二维码扫描
     */
    Native.scanBarcode = function(onSuccess, onFail) {
    	  cordova.exec(onSuccess, onFail, 'BarcodePlugin', 'scanBarcode', []);
    }
    
    /**
     * 生成二维码
     */
		Native.generateQRCode = function(options, onSuccess, onFail) {
   			var sourceString = options.sourceString || '';
  			cordova.exec(onSuccess, onFail, 'BarcodePlugin', 'generateQRCode', [sourceString]);
  	}
  	
  	/**
  	 * 保存二维码到相册
  	 */
	  Native.saveQRCode = function(sourcepath,onSuccess, onFail) {
			var sourcepath = sourcepath || '';
  		cordova.exec(onSuccess, onFail, 'BarcodePlugin', 'saveQRCode', [sourcepath]);
  	}
    
    
    /**
     * 参数说明 
     
     var options = {
     	inputType:0,  // 键盘类型，目前只支持0，1，2. 0表示数字键盘，不能输入小数点，1表示数字键盘，2表示全键盘
     	currentYPos:100 // 当前输入框在屏幕当中的位置，用来推动屏幕使用（当输入法可能盖住输入框的时候）
     };
     
     * 
     *
     */
    Native.showSafeKeyboard = function(options, onSuccess, onFail) {
    
    	var inputType = options.inputType;
    	var currentYPos = options.currentYPos;
    		
    	cordova.exec(onSuccess, onFail, 'SafeKeyboardPlugin', 'showSafeKeyboard', [inputType,currentYPos]);
    }
    
    /**
     * 关闭密码键盘   
     */
    Native.hideSafeKeyboard = function(onSuccess, onFail) {
			cordova.exec(onSuccess, onFail, 'SafeKeyboardPlugin', 'hideSafeKeyboard', []);
    }
    
    
    /**
     * TalkingData 事件监听
     */
   Native.talkingDataTrackEvent=function(eventId,onSuccess,onFail) {
		eventId = eventId || '';
		cordova.exec(onSuccess, onFail, 'TalkingData', 'trackEvent', [eventId]);
	 }
	 
  Native.talkingDataCollectUser = function(options,onSuccess, onFail) {
   var userID = options.userID;
    	var userType = options.userType;
	  
	 cordova.exec(onSuccess, onFail, 'TalkingData', 'collectUser', [userID,userType]);
  }
	  
  Native.talkingDataClearUser=function(onSuccess, onFail) { 
  cordova.exec(onSuccess, onFail, 'TalkingData', 'clearUser', []);
  }
	 
	/**
     * 打开一个新页面加载url
     */
    Native.openUrl = function(url, onSuccess, onFail) {
        cordova.exec(onSuccess, onFail, 'commTools', 'openUrl', [url]);
    }

    /**
     * 获取Native菜单列表
     */
    Native.getMenus = function(onSuccess, onFail) {
        cordova.exec(onSuccess, onFail, 'commTools', 'getMenus', []);
    }
    
    /**
     * 设置菜单列表到Native
     */
    Native.setMenus = function(menus, onSuccess, onFail) {
    	menus = menus || [];
        cordova.exec(onSuccess, onFail, 'commTools', 'setMenus', [menus]);
    }
    
    /**
     * 是否显示底部
     * flag为true表示显示，false表示不显示
     */
    Native.showBottm = function(flag, onSuccess, onFail) {
    	flag = flag || "false";
        cordova.exec(onSuccess, onFail, 'commTools', 'showBottm', [flag]);
    }
    
    
    /**
     * 应用升级
     * param:
     *  @param {Function} onSuccess回调参数:
     *      return param  无 
     *  @param {Function} onFail回调参数:
     *      return param {String} errorMsg 失败详情
     *  @param {String } downloadeUrl 更新地址 
     * 
     */
    Native.updateApplication = function(onSuccess, onFail, downloadUrl) {
        cordova.exec(onSuccess, onFail, 'commTools', 'updateApplication', [downloadUrl]);
    }
    
    
    /**
     * 获取当前应用的APPCONFIG
     */
    Native.getAppConfig = function(onSuccess, onFail) {
        cordova.exec(onSuccess, onFail, 'commTools', 'getAppConfig', []);
		}
		
		
		/*
	   根据cookie name删除指定的cookie
	   */
	  Native.deleteCookie = function(cookieName, onSuccess, onFail) {
	  	eventId = eventId || '';
	  	cordova.exec(onSuccess, onFail, 'CookieManager', 'deleteCookie', [cookieName]);
	  }



    