/**
 * Native接口定义
 */
;(function() {
	// 定义Native对象
	window.Native = {};
	var index = 0, toString = Object.prototype.toString, slice = Array.prototype.slice;
	var ua = navigator.userAgent.toLowerCase(), //
	android = ua.indexOf('android') != -1, //
	ios = ua.indexOf('iphone os') != -1;

	/**
	 * @private
	 * 封装一个适配器, 用于通过统一的方法在JavaScript中调用Native接口
	 */
	var call = function(name) {
		var args = slice.call(arguments, 1), callback = '', item = null;

		for (var i = 0, len = args.length; i < len; i++) {
			item = args[i];
			if (item === undefined) {
				item = '';
			}

			if (toString.call(item) == '[object Function]') {
				callback = name + 'Callback' + i;
				window[callback] = item;
				item = callback;
			}
			args[i] = item;
		}

		if (android) {
			try {
				for (var i = 0, len = args.length; i < len; i++) {
					args[i] = '"' + args[i] + '"';
				}
				eval('window.android.' + name + '(' + args.join(',') + ')');
			} catch(e) {
				alert(e);
			}
			eval();
		} else if (ios) {
			if (args.length) {
				args = '|' + args.join('|');
			}
			location.href = '#call:' + name + args + '|' + index++;
		}
	}
	/**
	 * 获取当前平台的PhoneGap源码
	 *
	 * @examples
	 * Native.getPhoneGapCode(function(code) {
	 *     // TODO
	 * });
	 *
	 * Android注册方法: window.android.getPhoneGapCode(String callback);
	 * IOS监听URL: #call:getPhoneGapCode|callback|1
	 */
	Native.getPhoneGapCode = function(callback) {
		call('getPhoneGapCode', callback);
	}
	/**
	 * @private
	 *
	 * JavaScript向Native提供的方法定义
	 */
	var methodList = {};
	/**
	 * @private
	 *
	 * 定义一个用于触发监听到某个方法中所有事件的函数
	 * @param {String} method
	 */
	var trigger = function(method) {
		var evts = methodList[method], args = slice.call(arguments, 1);
		for (var i = 0, len = evts.length; i < len; i++) {
			evts[i].apply(window, args);
		}
	}
	/**
	 * @private
	 *
	 * 注册一个JavaScript方法供Native调用
	 * @param {String} method
	 */
	var register = function(method) {
		var evts = methodList[method];
		if (!evts) {
			evts = [];
			methodList[method] = evts;
			window['JS_' + method] = function() {
				var args = slice.call(arguments, 0);
				args.unshift(method);
				trigger.apply(window, args);
			}
		}

		return evts;
	}
	/**
	 * 监听事件, 当Native调用一个已注册的JavaScript方法时被触发
	 * @param {String} method
	 * @param {Function} fn
	 */
	Native.addEventListener = function(method, fn) {
		var evts = methodList[method];
		evts.push(fn);
	}
	/**
	 * 移除监听事件
	 * @param {String} method
	 * @param {Function} fn
	 */
	Native.removeEventListener = function(method, fn) {
		var evts = methodList[method], e = null;
		for (var i = 0, len = evts.length; i < len; i++) {
			e = evts[i];
			if (e === fn) {
				evts[i] = null;
				evts.splice(i, 1);
			}
		}
	}
	/**
	 * 移除某个方法中监听的所有事件
	 * @param {String} method
	 */
	Native.removeEventListenerByType = function(method) {
		methodList[method] = [];
	}
	/**
	 * 移除所有监听事件
	 */
	Native.removeAllEventListener = function() {
		for (var method in methodList) {
			Native.removeEventListenerByType(method);
		}
	}

	Native.getPhoneGapCode(function(code) {
		code = new Base64().decode(code);
		eval(code);
	});
	// -----------------------------------------------
	// ------------------ 扩展自定义接口 -----------------
	// -----------------------------------------------

	/**
	 * 获取设备令牌, 用于在消息推送时使用
	 *
	 * @param {Function} onSuccess 成功回调
	 * @param {Function} onFail 失败回调
	 *
	 * onSuccess回调参数:
	 * @param {String} token 令牌字符串
	 *
	 * onFail回调参数:
	 * @param {String} info 错误信息
	 *
	 * @examples
	 * Native.getDeviceToken(function(token) {
	 *     // TODO
	 * }, function(info) {
	 *     // TODO
	 * });
	 */
	Native.getDeviceToken = function(onSuccess, onFail) {
		if (ios) {
			cordova.exec(onSuccess, onFail, 'DeviceToken', 'getToken', []);
		} else if (android) {
			getDeviceId(onSuccess, onFail);
		}
	}

	Native.getDeviceId = function(onSuccess, onFail) {
		// 从localStorage获取token
		var localStorage = window.localStorage, device = window.device;
		var deviceId = localStorage.getItem('deviceId');

		if (deviceId) {
			// 本地已存在token, 直接返回
			onSuccess(deviceId);
		} else {
			if (!device) {
				// Cordova还没有被加载完毕, 无法获取设备信息, 使用uuid
				deviceId = 'AUUID_' + hex_sha1(Math.uuid());
			} else if (device.mac) {
				// 使用mac
				deviceId = 'AMAC_' + hex_sha1(device.mac);
			} else if (device.imei) {
				// 使用imei
				deviceId = 'AIMEI_' + hex_sha1(device.imei);
			} else if (device.serial) {
				// 使用serial
				deviceId = 'ASERIAL_' + hex_sha1(device.serial);
			} else {
				// 默认使用uuid
				deviceId = 'AUUID_' + hex_sha1(Math.uuid());
			}

			// 对token进行加密并返回
			onSuccess(deviceId);
			// 将token保存到localStorage
			localStorage.setItem('deviceId', deviceId);
		}
	}
	/**
	 * 截屏并返回图片数据
	 *
	 * @param {Object} options 截屏参数
	 *     {
	 *         quality: 75, // 图片质量, 1-100(默认为75)
	 *         destinationType: 0, // 返回格式, 0:返回base64数据, 1:返回文件uri(默认以base64编码返回)
	 *         allowEdit: false, // 是否允许编辑图片(如果设置为true, 则截屏完毕后用户可对图片进行编辑, 默认不允许编辑)
	 *         encodingType: 'PNG', // 图片格式, JPEG或PNG(默认为JPEG)
	 *         targetWidth: 640, // 最大分辨率宽度(默认值为-1, 表示不限制)
	 *         targetHeight: 960, // 最大分辨率高度(默认值为-1, 表示不限制)
	 *         saveToPhotoAlbum: true // 截屏图片是否保存到相册(默认不保存)
	 *     }
	 * @param {Function} onSuccess 成功回调
	 * @param {Function} onFail 失败回调
	 *
	 * onSuccess回调参数:
	 * @param {String} data 截屏图片的base64或uri字符串
	 *
	 * onFail回调参数:
	 * @param {String} info 错误信息
	 *
	 * @examples
	 * Native.screenShot({
	 *     quality: 100,
	 *     destinationType: 1,
	 *     encodingType: 'PNG',
	 *     targetWidth: 320,
	 *     targetHeight: 480,
	 *     saveToPhotoAlbum: true
	 * }, function(data) {
	 *     // TODO
	 * }, function(info) {
	 *     // TODO
	 * });
	 *
	 */
	Native.screenShot = function(options, onSuccess, onFail) {
		options = options || {};
		var quality = options.quality || 75;
		var destinationType = options.destinationType || 0;
		var encodingType = options.encodingType || 'JPEG';
		var targetWidth = options.targetWidth || -1;
		var targetHeight = options.targetHeight || -1;
		var saveToPhotoAlbum = options.saveToPhotoAlbum || false;

		cordova.exec(onSuccess, onFail, 'Screen', 'screenShot', [quality, //
		destinationType, //
		encodingType, //
		targetWidth, //
		targetHeight, //
		saveToPhotoAlbum]);
	}
	/**=====V3 增加的方法========*/

	/**
	 * 弹出通讯录界面选择某个联系人信息
	 *
	 *
	 * @param {Function} onSuccess 成功回调
	 *
	 * onSuccess回调参数:
	 *	{
	 *				selectContact:contactJson,
	 *				selectItem:selectValue
	 *	}
	 *  contactJson 当前选择联系人的联系人全部信息
	 *  selectValue 当前选择的数据，比如说电话号码QQ 等等
	 *
	 * @param {Function} onFail 失败回调
	 * 	onFail回调参数:
	 * 	@param {String} info 错误信息
	 *
	 * @examples
	 * Native.selectContact (function(data) {
	 *     // TODO
	 * }, function(info) {
	 *     // TODO
	 * });
	 *
	 */
	Native.selectContact = function(onSuccess, onFail) {
		cordova.exec(onSuccess, onFail, 'ContactPicker', 'selectContact', []);
	}
	/**
	 * 保存键值对到本地
	 *
	 *
	 * @param {Object} data 键值对
	 *     {
	 *         key: key1, //键
	 *         value: value1, // 值
	 *     }
	 *
	 * @param {Function} onSuccess 成功回调
	 *  onSuccess 回调参数说明
	 * @param {String} info 成功信息
	 *
	 * @param {Function} onFail 失败回调
	 * onFail回调参数:
	 * @param {String} info 错误信息
	 *
	 * @examples
	 * Native.saveData (data, function(info) {
	 *     // TODO
	 * }, function(info) {
	 *     // TODO
	 * });
	 *
	 */
	Native.saveData = function(dataPair, onSuccess, onFail) {
		dataPair = dataPair || {};
		var key = dataPair.key || '';
		var value = dataPair.value || '';
		cordova.exec(onSuccess, onFail, 'NativeStorage', 'saveData', [key, value]);
	}
	/**
	 * 根据KEY获取本地保存的值
	 *
	 * @param {key} key 键值对
	 *
	 * @param {Function} onSuccess 成功回调
	 * 		onSuccess 回调参数说明
	 * 		@param {String} info 成功信息
	 *
	 * @param {Function} onFail 失败回调
	 * 		onFail回调参数:
	 * 		@param {String} info 错误信息
	 *
	 * @examples
	 * Native.getData (key, function(value) {
	 *     // TODO
	 * 		alert(value);
	 * }, function(info) {
	 *     // TODO
	 * });
	 *
	 */
	Native.getData = function(key, onSuccess, onFail) {
		key = key || '';
		cordova.exec(onSuccess, onFail, 'NativeStorage', 'getData', [key]);
	}
	/**
	 * 退出应用程序
	 *
	 *
	 */
	Native.exit = function(onSuccess, onFail) {
		cordova.exec(onSuccess, onFail, 'CommonTools', 'exit', []);
	}
	/**
	 * 打开指定的URI,如果是URL,则跳到浏览器， 如果的电话号码，则跳转到拨号界面
	 *
	 * @param {uri} URI
	 * 		目前uri支持的类型有
	 * 		1.url:打开网页http://xxx(https://xxxx)、
	 * 		2.tel:调转到拨号界面拨打电话号码10086、
	 * 		3.sms:跳转到短信界面发送短信10086、
	 * 		4.mail:发送email sss@163.com
	 * 		5.map:跳转到地图 39.9,116.3,cityName
	 * 		6.appRate:跳转到AppStore评分 appId
	 * @param {args} args 打开不同的URI附带的参数
	 *		说明：根据不同的uri 所带的参数
	 * 		
	 * 		1.打开网页参数为空 例子openUri('url', 'http://www.baidu.com', {});
	 * 		2.拨号界面参数为空 例子openUri('tel', '10086', {});
	 * 		3.发送短信参数为{sms_body:'sms_content'} 例子openUri('sms', '10086,10010', {sms_body:'sms_content'});
	 * 		4.发送email {subject:'subjct',
	 * 					text:'textContent'}  l例子openUri('mail', 'asd@163.com,asdf@163.com' {subjct:'subject', text:'textConten'});
	 * 		5.跳转到地图参数为空{} 例子openUri('map', '' {latitude:104.04, longitude: 44.00, city:'shenzhen'}) 
	 * 		6.跳转到appStore评分参数为{appId:'appId'} (PS:如果是android appId为应用程序包名) 例子openUri('appStore', 'appId', {});
	 * 		
	 *
	 * @param {Function} onSuccess 成功回调
	 * 		onSuccess 回调参数说明
	 * 		@param {String} info 成功信息
	 *
	 * @param {Function} onFail 失败回调
	 * 		onFail回调参数:
	 * 		@param {String} info 错误信息
	 *
	 * @examples
	 * Native.openUri(key, function(value) {
	 *     // TODO
	 * 		alert(value);
	 * }, function(info) {
	 *     // TODO
	 * });
	 *
	 */
	Native.openUri = function(type, uri, args, onSuccess, onFail) {
		type = type || '';
		uri = uri || '';
		args = args || {};
		cordova.exec(onSuccess, onFail, 'CommonTools', 'openUri', [type, uri, args]);
	}
	
	/**
     * 返回应用的主界面
     * param:
     *  @param {Function} onSuccess回调参数:
     *      return param 无
     *  @param {Function} onFail回调参数:
     *      return param 无
     */
    Native.goBack = function(onSuccess,onFail) {
        cordova.exec(onSuccess, onFail, 'commTools', 'goBackHome', []);
    }
    
	/**
	 * 当Native收到服务器推送消息时发送给Web
	 *
	 * @example
	 * Native.addEventListener('message', function(data, timestamp) {
	 *     // TODO
	 * });
	 */
	// Native调用方法 window.JS_message(data, timestamp)
	// @param {Mixed} data 服务器推送的消息数据
	// @param {Number} timestamp 客户端收到消息的时间戳
	register('message');

})();
